<#
.SYNOPSIS
Modifica i registri per mitigare gli effetti della vulnerabilita' Microsoft Office nel DDE (Microsoft Security Advisory 4053440)
.DESCRIPTION
Determina la versione di Office installata ed applica la correzione al ramo dei registri del utente.
Agisce sui prodotti Outlook, Word ed Excel nelle versioni 2010, 2013 e 2016.
ATTENZIONE - PER QUANTO LA PROCEDURA SIA STATA COLLAUDATA, DECLINIAMO OGNI RESPONSABILITA' PER EVENTUALI 
MALFUNZIONAMENTI O ANOMALIE LEGATE AL SISTEMA OPERATIVO E AI PROGRAMMI.
.EXAMPLE
-
.LINK
www.epolenghi.it
#>


$PathAEM = "c:\TempAEM"
$PathFIX = "c:\TempAEM\FIXdde2017"

if (Test-Path $PathFIX) {
  exit 0
} 

# Ricerca versione di office installata
$Office = Get-WmiObject -Class Win32_Product -filter "Name like '%Office%'" | select Version | Select -first 1 | foreach {$_.Version}

# Office 2010
if ($Office -like "14.*") {
  $Version = 1
  $RegistryVersion = "14.0"
}
# Office 2013
elseif ($Office -like "15.*") {
  $Version = 2
  $RegistryVersion = "15.0"
}
# Office 2016
elseif ($Office -like "16.*") {
  $Version = 3
  $RegistryVersion = "16.0"
}
# Office non installato o di versione precedente alla 2010 e quindi non supportata
else {
  exit 0
}

# Determina il nome del utente connesso al computer nella forma dominio\username
$UserName = Get-WMIObject -class Win32_ComputerSystem | select username | foreach { $_.username }
# Ottiene il nome dominio e il nome utente
$Domain,$UserName = $UserName.split("\\")
# Controlla che sia stato restituito un nome utente oppure esce con errore
if ($UserName) {
# Ottiene il SID del utente dopo aver determinato se la postazione è parte di un dominio o di un workgroup
  if ((Get-WmiObject -Class Win32_ComputerSystem).PartOfDomain) {
    $objUser = New-Object System.Security.Principal.NTAccount($Domain, $UserName)
    $strSID = $objUser.Translate([System.Security.Principal.SecurityIdentifier])
    $UserSID = $strSID.Value
  } else {
    $objUser = New-Object System.Security.Principal.NTAccount($UserName)
    $strSID = $objUser.Translate([System.Security.Principal.SecurityIdentifier])
    $UserSID = $strSID.Value
  }
} else {
  write-host "Impossibile trovare l'utente e applicare la patch"
  exit 1
}
# Costruisce il percorso finale della chiave di registro da creare e riempire
$RegistryPath = "HKU:\" + $UserSID + "\Software\Microsoft\Office\" + $RegistryVersion
$RegistryPathExcel = $RegistryPath + "\Excel\Security"
$RegistryPathWord = $RegistryPath + "\Word\Options"
$RegistryPathOutlook = $RegistryPath + "\Word\Options\WordMail"

# Crea un nuovo drive per permettere l'accesso alla sezione HKEY-USERS dei registri, con il nome HKU
New-PSDrive HKU Registry HKEY_USERS
# Memorizza il percorso di origine della PS
push-location
# Si posiziona nei registri all'interno del ramo SOFTWARE di Office dell'utente attivo
Set-location $RegistryPath
# Controlla la presenza di office prima della creazione dei valori
if (Test-Path Excel) {
  New-ItemProperty -Path $RegistryPathExcel -Name "WorkbookLinkWarnings" -Value "2" -PropertyType DWORD -Force | Out-Null
}
if (Test-Path Word) {
  New-ItemProperty -Path $RegistryPathWord -Name "DontUpdateLinks" -Value "1" -PropertyType DWORD -Force | Out-Null
  New-ItemProperty -Path $RegistryPathOutlook -Name "DontUpdateLinks" -Value "1" -PropertyType DWORD -Force | Out-Null
}
# Torna al percorso di origine della PS
pop-location

if (!(Test-Path $PathAEM)) {
  new-item -ItemType directory $PathFIX
}
else {
  if (!(Test-Path $PathFIX)) {
    cd $PathAEM
    new-item -ItemType directory FIXdde2017
  }
}
